***********
NIST Format
***********

The NIST file format is based on the `nonlinear regression <https://www.itl.nist.gov/div898/strd/nls/nls_main.shtml>`__ problems found at the `NIST Standard Reference Database <https://www.itl.nist.gov/div898/strd/>`__. Documentation and background of these problems can be found `here <https://www.itl.nist.gov/div898/strd/general/bkground.html>`__.

We note that FitBenchmarking recognizes the NIST file type by checking the first line of the file starts with `# NIST/ITL StRD`.
